Model Code:

.. literalinclude:: /../../cis_interface/examples/formatted_io4/src/formatted_io4_modelA.py
   :language: python
   :linenos:

.. literalinclude:: /../../cis_interface/examples/formatted_io4/src/formatted_io4_modelB.py
   :language: python
   :linenos:


(`Example in other languages <examples/formatted_io4.html>`__)
